@@ -5,10 +5,10 @@ from barbell2.castor import builders
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument('castor-export', help='Castor export Excel file')
-    parser.add_argument('dica-export', help='DHBA or DPCA export Excel data file')
-    parser.add_argument('dica-dd', help='DHBA or DPCA data dictionary')
-    parser.add_argument('output-dir', help='Output directory to store generated CSV files')
+    parser.add_argument('castor_export', help='Castor export Excel file')
+    parser.add_argument('dica_export', help='DHBA or DPCA export Excel data file')
+    parser.add_argument('dica_dd', help='DHBA or DPCA data dictionary')
+    parser.add_argument('output_dir', help='Output directory to store generated CSV files')
     args = parser.parse_args()
     cast_loader = loaders.CastorExportFileLoader(args.castor_export)
     cast_data = cast_loader.load()
@@ -19,4 +19,4 @@ def main():
     builder.save(args.output_dir)
 
 
-main()
+# main()
